@@ -1,7 +1,9 @@
+from functools import lru_cache
 from robot.libdocpkg import LibraryDocumentation
 from docgen import utils
 
 
+@lru_cache(maxsize=None)
 def load(value):
     """Parse library into container, with caching."""
     try:
